@@ -7,7 +7,7 @@ def get_all_urls():
         try:
             val = value[0][0][0]
             if isinstance(val, str) and isinstance(key, str):
-                result[key] = val
+                result[key] = f'/{val}'
         except:
             pass
     return result
